@@ -4,7 +4,7 @@ Layer module.
 from __future__ import absolute_import, unicode_literals
 import logging
 
-from psd_tools.constants import BlendMode, Tag
+from psd_tools.constants import BlendMode, Tag, Clipping
 from psd_tools.api.effects import Effects
 from psd_tools.api.mask import Mask
 from psd_tools.api.shape import VectorMask, Stroke, Origination
@@ -22,6 +22,7 @@ class Layer(object):
         self._channels = channels
         self._parent = parent
         self._clip_layers = []
+        self._has_clip_target = True
 
     @property
     def name(self):
@@ -65,6 +66,16 @@ class Layer(object):
         """
         return self.tagged_blocks.get_data(Tag.LAYER_ID, -1)
 
+    def _invalidate_bbox(self):
+        """
+        Invalidate this layer's _bbox and any parents recursively to the root.
+        """
+        current = self
+        while current is not None:
+            if hasattr(current, '_bbox'):
+                delattr(current, '_bbox')
+            current = current.parent
+
     @property
     def visible(self):
         """
@@ -76,6 +87,7 @@ class Layer(object):
 
     @visible.setter
     def visible(self, value):
+        self._invalidate_bbox()
         self._record.flags.visible = bool(value)
 
     def is_visible(self):
@@ -143,6 +155,7 @@ class Layer(object):
 
     @left.setter
     def left(self, value):
+        self._invalidate_bbox()
         w = self.width
         self._record.left = int(value)
         self._record.right = int(value) + w
@@ -158,6 +171,7 @@ class Layer(object):
 
     @top.setter
     def top(self, value):
+        self._invalidate_bbox()
         h = self.height
         self._record.top = int(value)
         self._record.bottom = int(value) + h
@@ -440,6 +454,20 @@ class Layer(object):
         """
         return self._clip_layers
 
+    @property
+    def clipping_layer(self):
+        """
+        Clipping flag for this layer. Writable.
+
+        :return: `bool`
+        """
+        return self._record.clipping == Clipping.NON_BASE
+
+    @clipping_layer.setter
+    def clipping_layer(self, value):
+        self._record.clipping = Clipping.NON_BASE if value else Clipping.Base
+        self._psd._compute_clipping_layers()
+
     def has_effects(self):
         """
         Returns True if the layer has effects.
